@@ -28,3 +28,20 @@ CREATE TABLE IF NOT EXISTS changes_user (
   newtext text
 ) engine = MyISAM;
 
+
+DROP PROCEDURE IF EXISTS upgrade_one;
+DELIMITER //
+CREATE PROCEDURE upgrade_one () 
+BEGIN
+  SET @version := (SELECT version FROM version WHERE NAME = 'changes_user');
+  IF @version IS NULL THEN 
+    ALTER TABLE changes_user ADD timestamp int AFTER username;
+    INSERT INTO version VALUES (NULL, 'changes_user', 1);
+  END IF;
+END;
+//
+DELIMITER ;
+CALL upgrade_one ();
+DROP PROCEDURE upgrade_one;
+
+
