@@ -1,4 +1,21 @@
 <?php
+/*
+Copyright (©) 2003-2013 Teus Benschop.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 3 of the License, or
+(at your option) any later version.
+ 
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+  
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+*/
 
  
 class notesTest extends PHPUnit_Framework_TestCase
@@ -301,19 +318,6 @@ class notesTest extends PHPUnit_Framework_TestCase
     @$identifier = $database_notes->storeNewNote ("", 0, 0, 0, "Summary", "Contents", false);
     $this->identifiers [] = $identifier;
 
-    // Test default privacy = 0.
-    $privacy = $database_notes->getPrivacy ($identifier);
-    $this->assertEquals (0, $privacy);
-
-    // Test setPrivacy.
-    $database_notes->setPrivacy ($identifier, 111);
-    $privacy = $database_notes->getPrivacy ($identifier);
-    $this->assertEquals (111, $privacy);
-
-    // Test getPossiblePrivacies.
-    $privacies = $database_notes->getPossiblePrivacies ();
-    $this->assertEquals (array (1, 2, 3, 4, 5, 6), $privacies);
-
     // Tear down.
     $database_notes->delete ($identifier);
     unset ($_SESSION);
