@@ -45,9 +45,13 @@ class booksTest extends PHPUnit_Framework_TestCase
 
   public function testInterpretBookEnglish()
   {
-    $this->assertEquals(1, Filter_Books::interpretBook ("Genesis"));
-    $this->assertEquals(46, Filter_Books::interpretBook ("1 Corinthians"));
-    $this->assertEquals(22, Filter_Books::interpretBook ("Song of Solomon"));
+    $this->assertEquals (1, Filter_Books::interpretBook ("Genesis"));
+    $this->assertEquals (46, Filter_Books::interpretBook ("1 Corinthians"));
+    $this->assertEquals (22, Filter_Books::interpretBook ("Song of Solomon"));
+    $this->assertEquals (60, Filter_Books::interpretBook ("I Peter"));
+    $this->assertEquals (63, Filter_Books::interpretBook ("II John"));
+    $this->assertEquals (64, Filter_Books::interpretBook ("III John"));
+
   }
 
 
