@@ -375,5 +375,18 @@ EOD;
   }
 
 
+  public function testExplodePath ()
+  {
+    $bookChapter = Filter_Git::explodePath ("Genesis/2/data");
+    $this->assertEquals (array ('book' => 1, 'chapter' => 2), $bookChapter);
+    $bookChapter = Filter_Git::explodePath ("Genesi/2/data");
+    $this->assertEquals (NULL, $bookChapter);
+    $bookChapter = Filter_Git::explodePath ("Exodus/3/data");
+    $this->assertEquals (array ('book' => 2, 'chapter' => 3), $bookChapter);
+    $bookChapter = Filter_Git::explodePath ("dictionary");
+    $this->assertEquals (NULL, $bookChapter);
+  }
+  
+
 }
 ?>
