@@ -25,14 +25,6 @@ class filterNotesTest extends PHPUnit_Framework_TestCase
   protected $note_identifiers = array ();
 
 
-  public function testPrivacy2text()
-  {
-    $this->assertEquals("Manager | Administrator", Filter_Notes::privacy2text (5));
-    $this->assertEquals("Guest | Member | Consultant | Translator | Manager | Administrator", Filter_Notes::privacy2text (0));
-    $this->assertEquals("", Filter_Notes::privacy2text (1000));
-  }
-
-
   public function testFilterNotesImportFromBibleditGtkFile()
   {
     $_SERVER['HTTP_USER_AGENT'] = "PHPUnit";
