@@ -1,4 +1,21 @@
 <?php
+/*
+Copyright (©) 2003-2013 Teus Benschop.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 3 of the License, or
+(at your option) any later version.
+ 
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+  
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+*/
 
  
 class sqlTest extends PHPUnit_Framework_TestCase
@@ -9,11 +26,6 @@ class sqlTest extends PHPUnit_Framework_TestCase
     $this->assertEquals (" SELECT identifier ", Filter_Sql::notesSelectIdentifier ());
   }
   
-  public function testConsiderPrivacy ()
-  {
-    $this->assertEquals (" AND (private <= 10) ", Filter_Sql::notesConsiderPrivacy (10));
-  }
-
   public function testOptionalFulltextSearchRelevanceStatement ()
   {
     $this->assertEquals (" ,  (MATCH (cleantext) AGAINST ('Note 10' IN NATURAL LANGUAGE MODE) * 10)  +  (MATCH (cleantext) AGAINST ('\"Note 10\"' IN BOOLEAN MODE) * 5)  +  (MATCH (cleantext) AGAINST ('Note 10*' IN BOOLEAN MODE)) + (MATCH (reversedtext) AGAINST ('01 etoN*' IN BOOLEAN MODE) * 1)  AS relevance ", Filter_Sql::notesOptionalFulltextSearchRelevanceStatement ("Note 10"));
