@@ -23,17 +23,21 @@ class filterTextTest extends PHPUnit_Framework_TestCase
 
 
 private $temporary_folder;
+private $frames_state;
+
 
 
   public function setUp ()
   {
-    $this->tearDown ();
+    $database_config_general = Database_Config_General::getInstance ();
+    $this->frames_state = $database_config_general->getExportChapterDropCaps ();
   }
 
   
   public function tearDown ()
   {
-
+    $database_config_general = Database_Config_General::getInstance ();
+    $database_config_general->setExportChapterDropCaps ($this->frames_state);
   }
 
 
@@ -43,6 +47,8 @@ private $temporary_folder;
   */
   public function testOne()
   {
+    $database_config_general = Database_Config_General::getInstance ();
+    $database_config_general->setExportChapterDropCaps (true);
 $usfm = <<<'EOD'
 \id GEN
 \h Header
