@@ -327,6 +327,20 @@ EOD;
     $this->assertEquals(array(0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19), Filter_Usfm::getVerseNumbers ($usfm));
   }
   
-  
+
+  public function testGetOpeningUsfm ()
+  {
+    $this->assertEquals ('\id ', Filter_Usfm::getOpeningUsfm ('id'));
+    $this->assertEquals ('\add ', Filter_Usfm::getOpeningUsfm ('add'));
+  }
+
+
+  public function testGetClosingUsfm ()
+  {
+    $this->assertEquals ('\wj*', Filter_Usfm::getClosingUsfm ('wj'));
+    $this->assertEquals ('\add*', Filter_Usfm::getClosingUsfm ('add'));
+  }
+
+
 }
 ?>
