@@ -22,15 +22,26 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 <head>
 <meta http-equiv="content-type" content="text/html; charset=UTF-8"></meta>
 <meta charset="utf-8" />
+<link rel="shortcut icon" href="../favicon.ico">
 <?php if (isset ($this->head_lines)) foreach ($this->head_lines as $line) echo "$line\n"; ?>
-<title><?php echo "$this->title" ?></title>
+<title><?php echo $this->title ?></title>
 <link rel="stylesheet" type="text/css" href="../css/stylesheet.css"></link>
 <script type="text/javascript" src="../jquery/jquery-1.10.2.min.js"></script>
 <?php if ($this->include_jquery_ui) { ?>
 <link rel="stylesheet" type="text/css" href="../jquery/jquery-ui-1.10.3.css"></link>
 <script type="text/javascript" src="../jquery/jquery-ui-1.10.3.<?php echo $this->include_jquery_ui_subset ?>min.js"></script>
 <?php } ?>
+<?php if ($this->included_stylesheet) { ?>
+<link rel="stylesheet" type="text/css" href="../dyncss/basic<?php echo $this->included_stylesheet ?>.css"></link>
+<?php } ?>
+<?php if ($this->included_editor_stylesheet) { ?>
+<link rel="stylesheet" type="text/css" href="../dyncss/editor<?php echo $this->included_editor_stylesheet ?>.css"></link>
+<link rel="stylesheet" type="text/css" href="../css/editor.css"></link>
+<?php } ?>
 <script type="text/javascript" src="../assets/header.js"></script>
+<?php if ($this->display_navigator) { ?>
+  <script type="text/javascript" src="../navigation/shortcuts.js"></script>
+<?php } ?>
 </head>
 <?php  
 echo "<body";
