@@ -18,6 +18,10 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 require_once ("../bootstrap/bootstrap.php");
 $view = new Assets_View (__FILE__);
+$menu_main = new Menu_Main ();
+$view->view->mainmenu = $menu_main->create ();
+$menu_user = new Menu_User ();
+$view->view->usermenu = $menu_user->create ();
 @$navigator = $_GET ['navigator'];
 if ($navigator) {
   $view->view->display_navigator = true;
