@@ -27,7 +27,6 @@ class Book_Create
   public static function create ($bible, $book, $chapter, &$feedback)
   {
     $database_bibles = Database_Bibles::getInstance ();
-    $database_snapshots = Database_Snapshots::getInstance();
     $database_versifications = Database_Versifications::getInstance();
     $database_books = Database_Books::getInstance();
     $database_logs = Database_Logs::getInstance ();
@@ -50,7 +49,6 @@ class Book_Create
       $data .= "\\h "     . $database_books->getEnglishFromId ($book) . "\n";
       $data .= "\\toc2 "  . $database_books->getEnglishFromId ($book) . "\n";
       $database_bibles->storeChapter ($bible, $book, 0, $data);
-      $database_snapshots->snapChapter ($bible, $book, 0, $data, false);
       $chaptersCreated [] = 0;
     }
 
@@ -69,7 +67,6 @@ class Book_Create
             $data .= "\\v $i\n";
           }
           $database_bibles->storeChapter ($bible, $book, $ch, $data);
-          $database_snapshots->snapChapter ($bible, $book, $ch, $data, false);
           $chaptersCreated [] = $ch;
         }
       }
