@@ -22,7 +22,7 @@ class Checks_Headers
 {
 
 
-  public function noPunctuationAtEnd ($bible, $book, $chapter, $headings, $centermarks, $endmarks)
+  public static function noPunctuationAtEnd ($bible, $book, $chapter, $headings, $centermarks, $endmarks)
   {
     if (!is_array ($headings)) return;
     $database_check = Database_Check::getInstance ();
