@@ -22,7 +22,7 @@ class Checks_Space
 {
 
 
-  public function doubleSpaceUsfm ($bible, $book, $chapter, $verse, $data)
+  public static function doubleSpaceUsfm ($bible, $book, $chapter, $verse, $data)
   {
     $database_check = Database_Check::getInstance ();
     $pos = strpos ($data, "  ");
@@ -35,7 +35,7 @@ class Checks_Space
   }
 
 
-  public function spaceBeforePunctuation ($bible, $book, $chapter, $texts)
+  public static function spaceBeforePunctuation ($bible, $book, $chapter, $texts)
   {
     if (!is_array ($texts)) return;
     $database_check = Database_Check::getInstance ();
