@@ -22,7 +22,7 @@ class Checks_Verses
 {
 
 
-  public function missingPunctuationAtEnd ($bible, $book, $chapter, $verses, $centermarks, $endmarks)
+  public static function missingPunctuationAtEnd ($bible, $book, $chapter, $verses, $centermarks, $endmarks)
   {
     if (!is_array ($verses)) return;
     $centermarks = explode (" ", $centermarks);
@@ -38,7 +38,7 @@ class Checks_Verses
   }
 
   
-  public function patterns ($bible, $book, $chapter, $verses, $patterns)
+  public static function patterns ($bible, $book, $chapter, $verses, $patterns)
   {
     if (!is_array ($verses)) return;
     if (!is_array ($patterns)) return;
