@@ -22,7 +22,7 @@ class Checks_Versification
 {
 
 
-  public function books ($bible, $books)
+  public static function books ($bible, $books)
   {
     $database_versifications = Database_Versifications::getInstance ();
     $standardBooks = $database_versifications->getBooks ("English");
@@ -38,7 +38,7 @@ class Checks_Versification
   }
 
 
-  public function chapters ($bible, $book, $chapters)
+  public static function chapters ($bible, $book, $chapters)
   {
     $database_versifications = Database_Versifications::getInstance ();
     $standardChapters = $database_versifications->getChapters ("English", $book, true);
@@ -54,7 +54,7 @@ class Checks_Versification
   }
 
   
-  public function verses ($bible, $book, $chapter, $verses)
+  public static function verses ($bible, $book, $chapter, $verses)
   {
     // Get verses in this chapter according to the versification system for the Bible.
     $database_versifications = Database_Versifications::getInstance ();
