@@ -207,8 +207,8 @@ class Database_Bibles
     $filter_text->initializeHeadingsAndTextPerVerse ();
     $usfm = $this->getChapter ($name, $book, $chapter);
     $filter_text->addUsfmCode ($usfm);
-    $database_config_user = Database_Config_User::getInstance ();
-    $stylesheet = $database_config_user->getStylesheet ();
+    $database_config_general = Database_Config_General::getInstance ();
+    $stylesheet = $database_config_general->getExportStylesheet ();
     $filter_text->run ($stylesheet);
 
     // The clean text to search on.
