@@ -51,8 +51,9 @@ class Database_ChangesUser
     $oldText = Database_SQLInjection::no ($oldText);
     $newID = Database_SQLInjection::no ($newID);
     $newText = Database_SQLInjection::no ($newText);
+    $time = time ();
     $database_instance = Database_Instance::getInstance();
-    $query = "INSERT INTO changes_user VALUES (NULL, '$username', '$bible', $book, $chapter, $oldID, '$oldText', '$newID', '$newText');";
+    $query = "INSERT INTO changes_user VALUES (NULL, '$username', $time, '$bible', $book, $chapter, $oldID, '$oldText', '$newID', '$newText');";
     $result = $database_instance->runQuery ($query);
   }
 
@@ -164,6 +165,24 @@ class Database_ChangesUser
   }
 
 
+  public function getTimestamp ($username, $bible, $book, $chapter, $newID)
+  {
+    $username = Database_SQLInjection::no ($username);
+    $bible = Database_SQLInjection::no ($bible);
+    $book = Database_SQLInjection::no ($book);
+    $chapter = Database_SQLInjection::no ($chapter);
+    $newID = Database_SQLInjection::no ($newID);
+    $database_instance = Database_Instance::getInstance();
+    $query = "SELECT timestamp FROM changes_user WHERE username = '$username' AND bible = '$bible' AND book = $book AND chapter = $chapter AND newid = $newID;";
+    $result = $database_instance->runQuery ($query);
+    for ($i = 0; $i < $result->num_rows; $i++) {
+      $row = $result->fetch_row ();
+      return $row [0];
+    }
+    return time ();
+  }
+
+
 }
 
 
