@@ -482,7 +482,7 @@ class Database_Config_User
   }
   public function setWorkbenchWidths ($value) {
     $this->setValue ("", "workbench-widths", $value);
-  }   
+  }
 
   public function getWorkbenchHeights () {
     return $this->getValue ("", "workbench-heights", "");
@@ -498,6 +498,20 @@ class Database_Config_User
     $this->setValue ("", "active-workbench", $value);
   }   
 
+  public function getPostponeNewNotesMails () {
+    return $this->getValue ("", "postpone-new-notes-mails", false);
+  }
+  public function setPostponeNewNotesMails ($value) {
+    $this->setValue ("", "postpone-new-notes-mails", $value);
+  }   
+
+  public function getRecentlyAppliedStyles () {
+    return $this->getValue ("", "recently-applied-styles", "p s add nd f x v");
+  }
+  public function setRecentlyAppliedStyles ($values) {
+    $this->setValue ("", "recently-applied-styles", $values);
+  }   
+
 }
 
 
