@@ -62,18 +62,21 @@ class Database_Mail
   
   
 
-  /**
-  * send - Send mail
-  */
-  public function send ($to, $subject, $body) {
-    $to      = Database_SQLInjection::no ($to);
+  // Send email.
+  // $to: The email address.
+  // $subject: The subject.
+  // $body: The body.
+  // $time: Normally not given, but if given, it indicates the $time stamp for sending this email.
+  public function send ($to, $subject, $body, $time = false) {
+    $to = Database_SQLInjection::no ($to);
     $subject = Database_SQLInjection::no ($subject);
-    $body    = Database_SQLInjection::no ($body);
-    $server  = Database_Instance::getInstance ();
-    $label   = $this->labelInbox ();
-    $time    = time();
-    $query   = "INSERT INTO mail VALUES (NULL, '$to',   $time, '$label', '$subject', '$body');";
-    $result  = $server->runQuery ($query);
+    $body = Database_SQLInjection::no ($body);
+    $label = $this->labelInbox ();
+    if ($time == false) $time = time();
+    $time = Database_SQLInjection::no ($time);
+    $server = Database_Instance::getInstance ();
+    $query = "INSERT INTO mail VALUES (NULL, '$to',   $time, '$label', '$subject', '$body');";
+    $server->runQuery ($query);
   }
 
 
@@ -140,14 +143,13 @@ class Database_Mail
   }
 
 
-  /**
-  * getMailsInboxes - get ids of all mails in all inboxes.
-  */
+  // getMailsInboxes - get ids of all mails in all inboxes reading for sending.
   public function getMailsInboxes () {
     $ids = array ();
     $server = Database_Instance::getInstance ();
     $label = $this->labelInbox();
-    $query = "SELECT id FROM mail WHERE label = '$label';";
+    $timestamp = time ();
+    $query = "SELECT id FROM mail WHERE label = '$label' AND timestamp <= $timestamp;";
     $result = $server->runQuery ($query);
     for ($i = 0; $i < $result->num_rows; $i++) {
       $result_array = $result->fetch_row();
