@@ -47,9 +47,8 @@ class Database_Users
   * getAdministratorCount - Returns how many administrators there are
   */
   public function getAdministratorCount() {
-    include ("session/levels.php");
     $server = Database_Instance::getInstance ();
-    $query = "SELECT * FROM users WHERE level = " . ADMIN_LEVEL;
+    $query = "SELECT * FROM users WHERE level = " . Filter_Roles::ADMIN_LEVEL . ";";
     $result = $server->runQuery ($query);
     return $result->num_rows; 
   }
@@ -172,8 +171,7 @@ class Database_Users
     $query = "SELECT level FROM users WHERE username = '$user';";
     $result = $server->runQuery ($query);
     if ($result->num_rows == 0) {
-      include ("session/levels.php");
-      return GUEST_LEVEL;
+      return Filter_Roles::GUEST_LEVEL;
     }
     $result_array = $result->fetch_array();
     return $result_array['level'];
@@ -209,8 +207,7 @@ class Database_Users
   */
   public function getAdministrator () {
     $server = Database_Instance::getInstance ();
-    include ("session/levels.php");
-    $query = "SELECT username FROM users WHERE level = " . ADMIN_LEVEL . ";";
+    $query = "SELECT username FROM users WHERE level = " . Filter_Roles::ADMIN_LEVEL . ";";
     $result = $server->runQuery ($query);
     if ($result->num_rows == 0)
       return "";
