@@ -52,6 +52,7 @@ var usfmClarifierTimeout;
 var usfmPreviousCaretTop;
 var usfmPreviousWidth;
 var usfmPreviousHeight;
+var usfmEditorTextChanged = false;
 
 
 function navigationNewPassage ()
@@ -114,6 +115,7 @@ function usfmEditorUnload ()
 
 function usfmEditorSaveChapter (sync)
 {
+  usfmEditorTextChanged = false;
   if (!usfmBible) return;
   if (!usfmBook) return;
   var usfm = $ ("#usfmeditor").text ();
@@ -137,6 +139,7 @@ function usfmEditorSaveChapter (sync)
 
 function usfmEditorChanged ()
 {
+  usfmEditorTextChanged = true;
   if (usfmEditorChangedTimeout) {
     clearTimeout (usfmEditorChangedTimeout);
   }
@@ -206,6 +209,10 @@ function usfmHandleKeyDown (event)
 
 function usfmHandleCaret ()
 {
+  if (usfmEditorTextChanged) {
+    usfmCaretChanged ();
+    return;
+  }
   if ($ ("#usfmeditor").is (":focus")) {
     var offset = getCaretPosition ();
     $.ajax ({
