@@ -21,19 +21,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 class Filter_Notes
 {
 
-  public static function privacy2text ($privacy)
-  {
-    include ("session/levels.php");
-    $text = "";
-    for ($i = GUEST_LEVEL; $i <= ADMIN_LEVEL; $i++) {
-      if ($i >= $privacy) {
-        if ($text != "") $text .= " | ";
-        $text .= $roles[$i];
-      }
-    }
-    return $text;
-  }
-  
   /**
   * This imports one note from Bibledit-Gtk. 
   * The note is available in $filename.
