@@ -406,6 +406,22 @@ class Filter_Usfm
     $verseNumber = trim ($verseNumber);
     return $verseNumber;
   }
+  
+  
+  // Takes a marker in the form of text only, like "id" or "add", 
+  // and converts it into opening USFM, like "\id " or "\add ".
+  public static function getOpeningUsfm ($text)
+  {
+    return "\\$text ";
+  }
+
+  // Takes a marker in the form of text only, like "add", 
+  // and converts it into closing USFM, like "\add*".
+  public static function getClosingUsfm ($text)
+  {
+    return "\\$text*";
+  }
+
 
 }
 
