@@ -23,10 +23,37 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 <p></p>
 <p></p>
 <p></p>
-<p></p>
-<p></p>
-<p></p>
-<p></p>
+
+<h2>Version in repository</h2>
+
+<h2>Version 1.3</h2>
+<p>11 November 2013</p>
+<p>Fixed: Bibledit focus clients fetch the wrong passage focus from Bibledit-Web.</p>
+<p>No animation anymore after clicking notes in the change notifications, or clicking passages.</p>
+<p>The Change History page displays where and when changes were made by whom.</p>
+<p>The Change History can be filtered on book / chapter / verse / author.</p>
+<p>The Workbench now also works in Firefox.</p>
+<p>When text has been added in the USFM editor near the end of a verse, the navigation no longer jumps to the next verse.</p>
+<p>The Change Notifications provide feedback about the active filter: all / personal / team.</p>
+<p>The widths of the columns in the sprint burndown chart are all equal.</p>
+<p>The Bible portions formatted to html use an external stylesheet instead of internal styles.</p>
+<p>Supports Ubuntu 13.10.</p>
+<p>The ./configure script checks for PHP JSON support.</p>
+<p>Fixed: In certain circumstances the "personal" change notifications are more than "all" of them.</p>
+<p>User setting for holding on to email generated when creating a consultation note, and send it in the evening.</p>
+<p>The keyboard shortcuts for the Navigator also work from within the Workbench.</p>
+<p>Alt-Down goes to the next verse, and Alt-Up goes to the previous verse.</p>
+<p>Security fix for revealing database password.</p>
+<p>Includes sample JavaScript for Adobe InDesign.</p>
+<p>Better uninstallation and faster configuration reload for web server.</p>
+<p>Installer requires package autoconf.</p>
+<p>Bible editor with formatted USFM.</p>
+<p>The Edit link starts the formatted Bible editor.</p>
+<p>The Translate link was renamed to [usfm].</p>
+<p>The focused control has a blue glow for easier operation by the keyboard.</p>
+<p>Mattias Põldaru styled the interface.</p>
+<p>The menus no longer self-organize based on the number of clicks.</p>
+<p>The Bible editor has a style button for applying a selection of the USFM styles.</p>
 
 <h2>Version 1.2</h2>
 <p>12 October 2013</p>
@@ -66,7 +93,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 <p>The text of the Dutch Statenbijbel has been added to the Resources.</p>
 <p>The Resources include the Dutch Statenbijbel Plus: The canonical text, plus headers, introductions, cross references, and notes.</p>
 <p>Clicking passages on some Resources navigates to that passage.</p>
-<p>Clicking a passage in the Change Notificatons navigates to that passage.</p>
+<p>Clicking a passage in the Change Notifications navigates to that passage.</p>
 <p>Two new resources: King James Version with only canonical text, and one with all the headers, introductions, cross references, and notes as well.</p>
 <p>The notes editor has some preset selections to be activated from the URL.</p>
 <p>Activating notes from the change notifications opens the notes in an existing note editor if available, else in a new tab in the browser.</p>
