@@ -22,7 +22,9 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 <p><a href="installation.php"><?php echo gettext ("Installation") ?></a></p>
 <p><a href="methodology.php"><?php echo gettext ("Methodology") ?></a></p>
 <p><a href="navigation.php"><?php echo gettext ("Navigation") ?></a></p>
+<p><a href="shortcuts.php"><?php echo gettext ("Keyboard shortcuts") ?></a></p>
 <p><a href="consultations.php"><?php echo gettext ("Consultations") ?></a></p>
 <p><a href="consistency.php"><?php echo gettext ("Consistency") ?></a></p>
 <p><a href="typesetting.php"><?php echo gettext ("Typesetting") ?></a></p>
+<p><a href="tipstricks.php"><?php echo gettext ("Tips and tricks") ?></a></p>
 <p><a href="about.php"><?php echo gettext ("About") ?></a></p>
