@@ -17,7 +17,7 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 ?>
-<h1><?php echo gettext ("Install Bibledit-Web 1.1 on Ubuntu 13.04") ?></h1>
+<h1><?php echo gettext ("Install Bibledit-Web 1.3 (not yet released) on Ubuntu 13.10") ?></h1>
 <p><?php echo gettext ("This assumes a standard installation of the operating system.") ?></p>
 <p><?php echo gettext ("Connect to or open a terminal.") ?></p>
 <p><?php echo gettext ("Update the software sources. Type the following command, and then press Enter.") ?></p>
@@ -35,17 +35,19 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 <p>When your web server works, the browser displays: It works!</p>
 
 <h2><?php echo gettext ("Install the software Bibledit-Web relies on") ?></h2>
-<p><?php echo gettext ("In the terminal issue these commands:") ?></p>
-<p><code>sudo apt-get install make git curl zip unzip libzend-framework-php wdiff sqlite3 php5-intl python perl libsword-utils rcs php5-gd</code></p>
+<p><?php echo gettext ("In the terminal issue this command:") ?></p>
+<p><code>sudo apt-get install make git curl zip unzip libzend-framework-php wdiff sqlite3 php5-intl python perl libsword-utils rcs php5-gd tidy php5-json autoconf</code></p>
 <p><?php echo gettext ("Anything to be set up, choose the default settings and enter the correct passwords.") ?></p>
 
 <h2><?php echo gettext ("Install Bibledit-Web") ?></h2>
 <p><?php echo gettext ("Download Bibledit-Web: Type the following command, and press Enter:") ?></p>
-<code>wget http://download.savannah.nongnu.org/releases/bibledit/source/web/bibledit-web-1.1.tar.gz</code>
+<code>wget http://download.savannah.nongnu.org/releases/bibledit-web/source/bibledit-web-1.3.tar.gz</code>
 <p><?php echo gettext ("Unpack Bibledit-Web: Type the following command, and press Enter:") ?></p>
-<code>tar zxf bibledit-web-1.1.tar.gz</code>
+<code>tar zxf bibledit-web-1.3.tar.gz</code>
 <p><?php echo gettext ("Enter Bibledit-Web's code: Type the following command, and press Enter:") ?></p>
-<code>cd bibledit-web-1.1</code>
+<code>cd bibledit-web-1.3</code>
+<p><?php echo gettext ("Reconfigure Bibledit-Web: Type the following command and press Enter:") ?></p>
+<code>autoreconf</code>
 <p><?php echo gettext ("Configure Bibledit-Web: Type the following command, replace 'password' with the administrative password of the mysql-server as entered above, and press Enter:") ?></p>
 <code>./configure --with-mysql-root-password=password</code>
 <p><?php echo gettext ("Install Bibledit-Web: Type the following command, and press Enter:") ?></p>
