@@ -32,7 +32,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 </p>
 <br>
 <p>
-  <?php echo gettext ("You can also use the keyboard to navigate.") ?>
+  <a href="navigation.php"><?php echo gettext ("You can also use the keyboard to navigate.") ?></a>
   <?php echo gettext ("Press Ctrl-G, enter the new passage, for example Mat 2 3, and press Enter.") ?>
   <?php echo gettext ("You can also enter the name of the book without chapter and verse, for example, Genesis, and it will go to that book.") ?>
   <?php echo gettext ("Or enter chapter and verse, for example 10 2, and it goes to that passage in the current book.") ?>
@@ -51,9 +51,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 <p><?php echo gettext ("The Navigator shows two arrows:") ?> ↶ <?php echo gettext ("and") ?> ↷</p>
 <p>↶ <?php echo gettext ("goes back in the navigation history.") ?></p>
 <p>↷ <?php echo gettext ("goes forward in the navigation history.") ?></p>
-<p><?php echo gettext ("Two keyboard shortcuts work the same.") ?></p>
-<p>Alt-Left Arrow: <?php echo gettext ("Go back.") ?></p>
-<p>Alt-Right Arrow: <?php echo gettext ("Go forward.") ?></p>
+<p><a href="navigation.php"><?php echo gettext ("There are also keyboard shortcuts for it.") ?></a></p>
 <br>
 <p>
   <?php echo gettext ("Some pages display one or more clickable passages.") ?>
