@@ -26,11 +26,8 @@ class Html_Text
   private $htmlDom;
   private $headDomNode;
   private $bodyDomNode;
-  private $styleDomNode;
   private $notesDivDomNode;
 
-  private $createdStyles; // An array with styles already created in the $stylesDom.
-
   public $currentPDomElement; // The current text:p DOMElement.
   private $currentPDomElementNameNode; // The DOMAttr of the name of the style of the current p element.
   public $currentParagraphStyle;
@@ -66,16 +63,16 @@ class Html_Text
     
     $this->bodyDomNode = $nodeList->item (1);
 
+/*
     $nodeList = $htmlXpath->query ("*", $this->headDomNode);
     foreach ($nodeList as $node) {
       if ($node->nodeName == "style") {
         $this->styleDomNode = $node;
       }
     }
+*/
     
     $this->notesDivDomNode = $this->newElement ("div");
-
-    $this->createdStyles = array ();
   }
 
   
@@ -138,65 +135,6 @@ class Html_Text
   }
 
 
-  /**
-  * This creates a paragraph style in the html file's internal css.
-  * $name: the name of the style, e.g. 'p'.
-  * $dropcaps: Not used. The variable is kept here so as to make it consistant with the OpenDocument routines.
-  */
-  public function createParagraphStyle ($name, $fontsize, $italic, $bold, $underline, $smallcaps, $alignment, $spacebefore, $spaceafter, $leftmargin, $rightmargin, $firstlineindent, $keepWithNext, $dropcaps)
-  {
-    // Start with the class. Notice the dot.
-    $css = ".$name { ";
- 
-    // Font size given in points.
-    $fontsize .= "pt";
-    $css .= "font-size: $fontsize; ";
-
-    // Italics, bold, underline, small caps can be either ooitOff or ooitOn for a paragraph.
-    if ($italic != ooitOff) {
-      $css .= "font-style: italic; ";
-    }
-    if ($bold != ooitOff) {
-      $css .= "font-weight: bold; ";
-    }
-    if ($underline != ooitOff) {
-      $css .= "text-decoration: underline; ";
-    }
-    if ($smallcaps != ooitOff) { 
-      $css .= "font-variant: small-caps; ";
-    }
-
-    // Text alignment can be: AlignmentLeft, AlignmentCenter, AlignmentRight, AlignmentJustify.
-    switch ($alignment) {
-      case AlignmentLeft:    $alignment = "left"; break;
-      case AlignmentCenter:  $alignment = "center"; break;
-      case AlignmentRight:   $alignment = "right"; break;
-      case AlignmentJustify: $alignment = "justify"; break;
-    }
-    $css .= "text-align: $alignment; ";
-
-    // Paragraph measurements; given in mm.
-    $spacebefore .= "mm";
-    $css .= "margin-top: $spacebefore; ";
-    $spaceafter .= "mm";
-    $css .= "margin-bottom: $spaceafter; ";
-    $leftmargin .= "mm";
-    $css .= "margin-left: $leftmargin; ";
-    $rightmargin .= "mm";
-    $css .= "margin-right: $rightmargin; ";
-    $firstlineindent .= "mm";
-    $css .= "text-indent: $firstlineindent; ";
-
-    if ($keepWithNext) {
-      $css .= "page-break-inside: avoid; ";
-      // Not yet implemented: "keep-with-next", "always";
-    }
-
-    $css .= "}\n";
-    $this->styleDomNode->nodeValue .= $css;
-  }
-
-
   /**
   * This opens a text style.
   * $style: the array containing the style variables.
@@ -205,47 +143,6 @@ class Html_Text
   public function openTextStyle ($style, $note = false)
   {
     $marker = $style["marker"];
-    if (!in_array ($marker, $this->createdStyles)) {
-      @$italic = $style["italic"];
-      @$bold = $style["bold"];
-      @$underline = $style["underline"];
-      @$smallcaps = $style["smallcaps"];
-      @$superscript = $style["superscript"];
-      @$color = $style["color"];
-      $this->createdStyles [] = $marker;
-
-      // Start with the class. Notice the dot.
-      $css = ".$marker { ";
- 
-      // Italics, bold, underline, small caps can be ooitOff or ooitOn or ooitInherit or ooitToggle.
-      // Not all features are implemented.
-      if (($italic == ooitOn) || ($italic == ooitToggle)) {
-        $css .= "font-style: italic; ";
-      }
-      if (($bold == ooitOn) || ($bold == ooitToggle)) {
-        $css .= "font-weight: bold; ";
-      }
-      if (($underline == ooitOn) || ($underline == ooitToggle)) {
-        $css .= "text-decoration: underline; ";
-      }
-      if (($smallcaps == ooitOn) || ($smallcaps == ooitToggle)) { 
-        $css .= "font-variant: small-caps; ";
-      }
-
-      if ($superscript) {
-        $css .= "font-size: x-small; ";
-        $css .= "vertical-align: super; ";
-      }
-
-      if ($color != "000000") {
-        $css .= "color: #$color; ";
-      }
-
-      $css .= "}\n";
-      $this->styleDomNode->nodeValue .= $css;
-
-    }
-
     if ($note) $this->currentNoteTextStyle = $marker;
     else $this->currentTextStyle = $marker;
   }
@@ -282,8 +179,7 @@ class Html_Text
     // Add the link with all relevant data for the note citation.
     $reference = "#note" . $this->noteCount;
     $identifier = "citation" . $this->noteCount;
-    $title = gettext ("See footnote");
-    $this->addLink ($this->currentPDomElement, $reference, $identifier, $title, "superscript", $citation);
+    $this->addLink ($this->currentPDomElement, $reference, $identifier, "", "superscript", $citation);
 
     // Open a paragraph element for the note body.
     $this->notePDomElement = $this->newElement ("p");
@@ -295,8 +191,7 @@ class Html_Text
     // Add the link with all relevant data for the note body.
     $reference = "#citation" . $this->noteCount;
     $identifier = "note" . $this->noteCount;
-    $title = gettext ("Return to text");
-    $this->addLink ($this->notePDomElement, $reference, $identifier, $title, "", $citation);
+    $this->addLink ($this->notePDomElement, $reference, $identifier, "", "", $citation);
 
     // Add a space.
     $this->addNoteText (" ");
@@ -352,7 +247,7 @@ class Html_Text
     $domNode->appendChild ($aDomElement);
     $aDomElement->setAttribute ("href", $reference);
     $aDomElement->setAttribute ("id", $identifier);
-    $aDomElement->setAttribute ("title", $title);
+    if ($title) $aDomElement->setAttribute ("title", $title);
     if ($style != "") $aDomElement->setAttribute ("class", $style);
     $aDomElement->nodeValue = htmlspecialchars ($text, ENT_QUOTES, "UTF-8");
   }
@@ -374,6 +269,27 @@ class Html_Text
     $string = $this->htmlDom->saveHTML ();
     return $string;
   }
+  
+  
+  // Returns the html text within the <body> tags, that is, without the <head> stuff.
+  public function getInnerHtml ()
+  {
+    $page = $this->getHtml ();
+    $pos = strpos ($page, '<body>');
+    if ($pos !== false) {
+      $page = substr ($page, $pos + 7);
+      $pos = strpos ($page, '</body>');
+      if ($pos !== false) {
+        $page = substr ($page, 0, $pos - 1);
+      }
+    }
+    // Remove the empty <div> element at the end.
+    $pos = strpos ($page, '<div></div>');
+    if ($pos !== false) {
+      $page = substr ($page, 0, $pos);
+    }
+    return $page;
+  }
 
 
   /**
