@@ -17,21 +17,5 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 ?>
-
-<textarea name="area1" class="fullwidth"></textarea>
-
-<script type="text/javascript" src="nicEdit.js"></script>
-
-<script type="text/javascript">
-	bkLib.onDomLoaded(function() { nicEditors.allTextAreas() });
-</script>
-
-<script type="text/javascript">
-  $ ("body").on ("paste", function (e) {
-console.log ("paste");
-    var data = e.originalEvent.clipboardData.getData ('Text');
-    e.preventDefault();
-    document.execCommand ("insertHTML", false, data);
-  });
-
-</script>
+<p>Test page</p>
+<script type="text/javascript" src="test.js"></script>
