@@ -28,6 +28,13 @@ $id = $_GET['id'];
 if (!isset ($id)) $id = 0;
 
 
+// Bibledit-* clients don't include the 'focus' command.
+// So if no command is included, assume it's the 'focus' command that's intended.
+@$command = $_GET ['command'];
+if (!isset ($command)) $command = "focus";
+
+
+
 $database_ipc = Database_Ipc::getInstance();
 
 
@@ -43,7 +50,7 @@ while (!is_array ($values)) {
   sleep (1);
   $counter++;
   if ($counter > 600) $id--;
-  $values = $database_ipc->retrieveMessage ($id, $user, $channel);
+  $values = $database_ipc->retrieveMessage ($id, $user, $channel, $command);
 }
 
 
