@@ -15,8 +15,9 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
+
 $(window).load (function () {
-  $("body").animate({ scrollTop: $(document).height() - $(window).height() }, 3000);
+  $("body").animate({ scrollTop: $(document).height() - $(window).height() + 15 }, 3000);
 });
 
 var getMore = function () 
@@ -27,7 +28,7 @@ var getMore = function ()
     } else {
       response = $.parseJSON (response);
       lastID = response ["id"];
-      $ ("div").append ($ ("<p>" + response ["entry"] + "</p>"));
+      $ ("#logbook").append ($ ("<p>" + response ["entry"] + "</p>"));
       $("body").animate({ scrollTop: $(document).height() - $(window).height() }, 100);
       setTimeout (getMore, 100);
     }
