@@ -29,7 +29,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
   |
   <a href="?day=3"><?php echo gettext ("three days ago"); ?></a>
 </p>
-<div>
+<div id="logbook">
 <?php  
 foreach ($this->lines as $line) {
   echo "<p>$line</p>\n";
