@@ -18,7 +18,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 require_once ("../bootstrap/bootstrap.php");
-page_access_level (MANAGER_LEVEL);
+page_access_level ((Filter_Roles::MANAGER_LEVEL));
 Assets_Page::header (gettext ("Removing duplicate consultation notes"));
 set_time_limit (0);
 $workingdirectory = dirname (__FILE__);
