@@ -24,10 +24,6 @@ class Notes_Logic
   private static $instance;
 
 
-  private function __construct() {
-  } 
-
-
   const notifyNoteNew             = 1;
   const notifyNoteComment         = 2;
   const notifyNoteUpdate          = 3;
@@ -35,6 +31,10 @@ class Notes_Logic
   const notifyMarkNoteForDeletion = 5;
 
 
+  private function __construct() {
+  } 
+
+
   public static function getInstance() 
   {
     if (empty (self::$instance)) {
@@ -76,7 +76,7 @@ class Notes_Logic
       $database_notes = Database_Notes::getInstance();
       $assignees = $database_notes->getAssignees ($identifier);
       if (!in_array ($user, $assignees)) {
-        $this->emailUsers ($identifier, gettext ("Assigned"), array ($user));
+        $this->emailUsers ($identifier, gettext ("Assigned"), array ($user), false);
       }
     }
   }
@@ -180,9 +180,17 @@ class Notes_Logic
       case self::notifyNoteDelete          : $label = gettext ("Deleted");             break;
       case self::notifyMarkNoteForDeletion : $label = gettext ("Marked for deletion"); break;
     }
+
+    // Optional postponing sending email.    
+    $postpone = false;
+    if ($notification == self::notifyNoteNew) {
+      if ($database_config_user->getPostponeNewNotesMails ()) {
+        $postpone = true;
+      }
+    }
     
     // Send mail to all recipients.
-    $this->emailUsers ($identifier, $label, $recipients);
+    $this->emailUsers ($identifier, $label, $recipients, $postpone);
   }
 
 
@@ -191,8 +199,9 @@ class Notes_Logic
   * $identifier: the note that is being handled.
   * $label: prefix to the subject line of the email.
   * $users: array of users to be mailed.
+  * $postpone: whether to postpone sending the email till the evening.
   */
-  private function emailUsers ($identifier, $label, $users)
+  private function emailUsers ($identifier, $label, $users, $postpone)
   {
     // Databases.
     $database_notes = Database_Notes::getInstance();
@@ -205,6 +214,7 @@ class Notes_Logic
     $summary = $database_notes->getSummary ($identifier);
     $passages = Filter_Books::passagesDisplayInline ($database_notes->getPassages ($identifier));
     $contents = $database_notes->getContents ($identifier);
+
     // Include a link to the note on the site.
     $contents .= "<br>\n";
     $siteUrl = $database_config_general->getSiteURL ();
@@ -212,8 +222,17 @@ class Notes_Logic
     $contents .= "<p><a href=\"$link\">View or respond online</a></p>\n";
     $mailto = "mailto:" . $database_config_general->getSiteMailAddress () . "?subject=(CNID$identifier)";
     $contents .= "<p><a href=\"$mailto\">Respond by email</a></p>\n";
+
+    // Deal with possible postponing email.
+    $timestamp = time ();
+    if ($postpone) {
+      $postpone = strtotime ("today +21 hours");
+      if ($postpone > $timestamp) $timestamp = $postpone;
+    }
+
+    // Send.
     foreach ($users as $user) {
-      $database_mail->send ($user, "$label | $passages | $summary | (CNID$identifier)", $contents);
+      $database_mail->send ($user, "$label | $passages | $summary | (CNID$identifier)", $contents, $timestamp);
     }
   }
   
