@@ -18,7 +18,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 ?>
 <p>
-  <span><?php echo $this->navigationHtml ?></span>
+  <?php echo gettext ("Notes") ?>
   |
   <a href="select.php">[<?php echo gettext ("select") ?>]</a>
   <?php if ($this->level >= 5) { ?>
@@ -31,4 +31,4 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 <br>
 <div id="noteslist"><?php echo gettext ("Loading...") ?></div>
 <script type="text/javascript" src="index.js"></script>
-<?php echo $this->navigationCode; ?>
+<script type="text/javascript" src="poll.js"></script>
