@@ -19,7 +19,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 
 require_once ("../bootstrap/bootstrap.php");
-page_access_level (MANAGER_LEVEL);
+page_access_level ((Filter_Roles::MANAGER_LEVEL));
 $header = new Assets_Header (gettext ("Convert"));
 $header->run ();
 $view = new Assets_View (__FILE__);
