@@ -16,12 +16,26 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 $(document).ready (function () {
-  $(document).on ("passage", loadResources);
+  navigationNewPassage ();
 });
 
 
-function loadResources ()
+function navigationNewPassage ()
 {
+  var resourceBook;
+  var resourceChapter;
+  var resourceVerse;
+  if (typeof navigationBook != 'undefined') {
+    resourceBook = navigationBook;
+    resourceChapter = navigationChapter;
+    resourceVerse = navigationVerse;
+  } else if (parent.window.navigationBook != 'undefined') {
+    resourceBook = parent.window.navigationBook;
+    resourceChapter = parent.window.navigationChapter;
+    resourceVerse = parent.window.navigationVerse;
+  } else {
+    return;
+  }
   for (i = 0; i < resourceCount; i++) {
     var container = $ ("#bibledit" + i);
     container.empty ();
@@ -30,10 +44,11 @@ function loadResources ()
       context: container,
       url: "get.php",
       type: "GET",
-      data: { resource: i, book: navigationBook, chapter: navigationChapter, verse: navigationVerse },
+      data: { resource: i, book: resourceBook, chapter: resourceChapter, verse: resourceVerse },
       success: function (response) {
         this.empty ();
-        this.append ($ (response));
+        this.append (response);
+        navigationSetup ();
       },
     });
   }
