@@ -17,15 +17,16 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 ?>
-<div><?php echo $this->navigationHtml ?></div>
-<h4><?php echo gettext ("Resources") ?></h4>
+<p>
+  <?php echo gettext ("Resources") ?>
+  <a href="organize.php">[<?php echo gettext ("organize") ?>]</a>
+</p>
 <hr>
 <?php foreach ($this->resources as $offset => $resource) { ?>
   <p><?php echo $resource ?></p>
   <div id="bibledit<?php echo $offset ?>"></div>
   <hr>
 <?php } ?>
-<p><a href="settings.php">[<?php echo gettext ("settings") ?>]</a></p>
 <script><?php echo $this->script; ?></script>
 <script type="text/javascript" src="index.js"></script>
-<?php echo $this->navigationCode; ?>
+<script type="text/javascript" src="../navigation/nav.js"></script>
