@@ -28,23 +28,18 @@ class SendReceive_Logic
   static public function start ()
   {
     $timer_logger = new Timer_Logger ();
-    $workingdirectory = escapeshellarg (dirname (__FILE__));
-    $logfilename = $timer_logger->getLogFilename (Timer_Logger::sendreceive);
-    $command = "cd $workingdirectory; php sendreceive.php > $logfilename 2>&1 & echo $!";
-    $pid = shell_exec ($command);
-    $timer_logger->registerLogfile ($command, $pid, $logfilename);
+    $timer_logger->startProcess (dirname (__FILE__), "php", "sendreceive.php", NULL, "sendreceive");
   }
 
 
   static public function isRunning ()
   {
-    $timer_logger = new Timer_Logger ();
     $database_logger = Database_Logger::getInstance ();
-    $filename = $timer_logger->getLogFilename (Timer_Logger::sendreceive);
-    $pid = $database_logger->getPID ($filename);
-    return $pid;
+    $count = $database_logger->count ("sendreceive");
+    return ($count > 0);
   }
 
+
 }
 
 
