@@ -18,7 +18,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
     
 require_once ("../bootstrap/bootstrap.php");
-page_access_level (GUEST_LEVEL);
+page_access_level ((Filter_Roles::GUEST_LEVEL));
 
 $session_logic = Session_Logic::getInstance ();
 $session_logic->logout ();
