@@ -19,7 +19,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
     
 
 require_once ("../bootstrap/bootstrap.php");
-page_access_level (GUEST_LEVEL);
+page_access_level ((Filter_Roles::GUEST_LEVEL));
 Assets_Page::header (gettext ("Signup"));
 
 
@@ -96,8 +96,7 @@ if (isset($_POST['submit'])) {
     $confirm_worker = Confirm_Worker::getInstance ();
     $initial_subject = gettext ("Signup verification");
     $initial_body = gettext ("Somebody requested to open an account with this email address.");
-    include ("session/levels.php");
-    $query = $database_users->addNewUserQuery ($user, $pass, MEMBER_LEVEL, $mail);
+    $query = $database_users->addNewUserQuery ($user, $pass, Filter_Roles::MEMBER_LEVEL, $mail);
     $subsequent_subject = gettext ("Account opened");
     $subsequent_body = gettext ("Welcome! Your account is now active.");
     $confirm_worker->setup ($mail, $initial_subject, $initial_body, $query, $subsequent_subject, $subsequent_body);
