@@ -19,7 +19,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 
 require_once ("../bootstrap/bootstrap.php");
-page_access_level (TRANSLATOR_LEVEL);
+page_access_level ((Filter_Roles::TRANSLATOR_LEVEL));
 
 
 $view = new Assets_View (__FILE__);
@@ -73,16 +73,19 @@ if (isset ($title)) {
 }
 
 
-$header->run ();
-
-
 @$mail = $_GET ['mail'];
 if (isset ($mail)) {
   Sprint_Logic::burndown (true);
   $view->view->success = gettext ("The information was mailed to the subscribers");
+  // Give the burndown logic time to update the sprint history,
+  // so the page will display the updated burndown chart.
+  usleep (200000);
 }
 
 
+$header->run ();
+
+
 @$id = $_GET ['id'];
 
 
