@@ -119,7 +119,7 @@ class Sprint_Logic
     // Write number of days along the x-axis.
     $lines [] = '<tr>';
     foreach ($data as $day => $tasks) {
-      $lines [] = "<td>$day</td>";
+      $lines [] = "<td style=\"width:1em\">$day</td>";
     }
     $lines [] = "</tr>";
 
