@@ -19,7 +19,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 
 require_once ("../bootstrap/bootstrap.php");
-page_access_level (MANAGER_LEVEL);
+page_access_level ((Filter_Roles::MANAGER_LEVEL));
 
 Assets_Page::header (gettext ("Style"));
 
@@ -572,6 +572,11 @@ if (isset($_POST['userstring2'])) {
 if ($userstring2 == "") $userstring2 = "--";
 $view->view->userstring2 = Filter_Html::sanitize ($userstring2);
 
+// Recreate stylesheets after editing a style.
+if ((count ($_GET) != 2) || (count ($_POST) != 0)) {
+  Styles_Sheets::create_all ();
+}
+
 // Userstring3 not yet used.
 
 $view->render ("view.php");
