@@ -130,6 +130,15 @@ foreach ($bibles as $bible) {
   unset ($contents);
   unset ($host);
 
+  // Stylesheets for both web exports.
+  $styles_sheets = new Styles_Sheets ();
+  $path = "$plainWebDirectory/stylesheet.css";
+  $styles_sheets->create ($stylesheet, $path, false, true);
+  $path = "$richWebDirectory/stylesheet.css";
+  $styles_sheets->create ($stylesheet, $path, false, true);
+  unset ($path);
+  unset ($styles_sheets);
+  
   // Back link path.
   $backLinkPath = "../downloads/exports/$bible/web/";
 
