@@ -39,6 +39,9 @@ ignore_user_abort (true);
 set_time_limit (0);
 
 
+include ("paths/paths.php");
+
+
 $config_general = Database_Config_General::getInstance ();
 $database_logs = Database_Logs::getInstance ();
 $timer_logger = new Timer_Logger ();
@@ -110,6 +113,14 @@ if (($current_timestamp >= $config_general->getTimerDiff ()) || (($hour == 0) &&
 }
 
 
+// Comb through the git log and add the change to the history.
+if (($hour == 0) && ($minute == 30)) {
+  $directory = dirname (dirname (__FILE__)) . "/changes";
+  $timer_logger->startProcess ($directory, "php", "git.php", NULL, NULL, true);
+  unset ($directory);
+}
+
+
 // Run the checks on the Bibles.
 // This takes 15 minutes on a production machine with two Bibles.
 if (($current_timestamp >= $config_general->getTimerChecks ()) || (($hour == 0) && ($minute == 30))) {
@@ -119,7 +130,7 @@ if (($current_timestamp >= $config_general->getTimerChecks ()) || (($hour == 0)
 
 
 // Database maintenance and trimming.
-// It takes a few minutes on a production machine..
+// It takes a few minutes on a production machine.
 if (($hour == 0) && ($minute == 50)) {
   $timer_logger->startProcess (dirname (__FILE__), "php", "database.php", NULL, NULL, true);
 }
@@ -153,6 +164,14 @@ if ($burndown) {
 unset ($burndown);
 
 
+// A flag is set upon installation, so it (re)generates the stylesheets once.
+$create_css_flag = "$localStatePath/$location/create_css_flag";
+if (file_exists ($create_css_flag)) {
+  unlink ($create_css_flag);
+  Styles_Sheets::create_all ();
+}
+
+
 // Export the Bibles to the various output formats.
 // This may take an hour on a production machine.
 if (($current_timestamp >= $config_general->getTimerExports ()) || (($hour == 1) && ($minute == 10))) {
