@@ -37,6 +37,7 @@ $database_mail = Database_Mail::getInstance ();
 $database_bibles = Database_Bibles::getInstance ();
 $database_changesuser = Database_ChangesUser::getInstance ();
 $database_changes = Database_Changes::getInstance ();
+$database_history = Database_History::getInstance ();
 
 
 // Go through the users who have made changes in the Bible through the web editor.
@@ -72,7 +73,7 @@ foreach ($users as $user) {
           $newId = $IdSet ['newid'];
 
           if ($restart) {
-            processIdentifiers ($user, $bible, $book, $chapter, $referenceNewId, $newId, $email, $database_changes);
+            processIdentifiers ($user, $bible, $book, $chapter, $referenceNewId, $newId, $email, $database_changes, $database_history);
             $referenceOldId = $oldId;
             $referenceNewId = $newId;
             $lastNewId = $newId;
@@ -89,7 +90,7 @@ foreach ($users as $user) {
         }
         
         // Process the last set of identifiers.
-        processIdentifiers ($user, $bible, $book, $chapter, $referenceNewId, $newId, $email, $database_changes);
+        processIdentifiers ($user, $bible, $book, $chapter, $referenceNewId, $newId, $email, $database_changes, $database_history);
 
       }
     }
@@ -112,7 +113,7 @@ foreach ($users as $user) {
 $database_logs->log (gettext ("userchanges: Completed"));
 
 
-function processIdentifiers ($user, $bible, $book, $chapter, $oldId, $newId, &$email, $database_changes)
+function processIdentifiers ($user, $bible, $book, $chapter, $oldId, $newId, &$email, $database_changes, $database_history)
 {
   if ($oldId != 0) {
     $database_changesuser = Database_ChangesUser::getInstance ();
@@ -120,11 +121,12 @@ function processIdentifiers ($user, $bible, $book, $chapter, $oldId, $newId, &$e
     $database_config_user = Database_Config_User::getInstance ();
     $database_bibles = Database_Bibles::getInstance ();
     $bibleID = $database_bibles->getID ($bible);
-    $stylesheet = $database_config_general->getExportStylesheet ();
+    $stylesheet = $database_config_user->getStylesheet ();
     $old_chapter_usfm = $database_changesuser->getChapter ($user, $bible, $book, $chapter, $oldId);
     $old_chapter_usfm = $old_chapter_usfm ['oldtext'];
     $new_chapter_usfm = $database_changesuser->getChapter ($user, $bible, $book, $chapter, $newId);
     $new_chapter_usfm = $new_chapter_usfm ['newtext'];
+    $timestamp = $database_changesuser->getTimestamp ($user, $bible, $book, $chapter, $newId);
     $old_verse_numbers = Filter_Usfm::getVerseNumbers ($old_chapter_usfm);
     $new_verse_numbers = Filter_Usfm::getVerseNumbers ($new_chapter_usfm);
     $verses = array_merge ($old_verse_numbers, $new_verse_numbers);
@@ -144,8 +146,8 @@ function processIdentifiers ($user, $bible, $book, $chapter, $oldId, $newId, &$e
         $filter_text_new->addUsfmCode ($new_verse_usfm);
         $filter_text_old->run ($stylesheet);
         $filter_text_new->run ($stylesheet);
-        $old_html = $filter_text_old->html_text_standard->getHtml ();
-        $new_html = $filter_text_new->html_text_standard->getHtml ();
+        $old_html = $filter_text_old->html_text_standard->getInnerHtml ();
+        $new_html = $filter_text_new->html_text_standard->getInnerHtml ();
         $old_text = $filter_text_old->text_text->get ();
         $new_text = $filter_text_new->text_text->get ();
         if ($old_text != $new_text) {
@@ -159,6 +161,7 @@ function processIdentifiers ($user, $bible, $book, $chapter, $oldId, $newId, &$e
             $changeNotificationUsers = array ($user);
             $database_changes->record ($changeNotificationUsers, "☺", $bibleID, $book, $chapter, $verse, $old_html, $modification, $new_html);
           }
+          $database_history->record ($timestamp, $user, $bible, $book, $chapter, $verse, $old_html, $modification, $new_html);
         }
       }
     }
