@@ -18,7 +18,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 require_once ("../bootstrap/bootstrap.php");
-page_access_level (MEMBER_LEVEL);
+page_access_level ((Filter_Roles::MEMBER_LEVEL));
 
 Assets_Page::header (gettext ("Mail"));
 $view = new Assets_View (__FILE__);
